==> mct_nightly-1.7.1.3012023.post343-py3-none-any.whl: model_compression_toolkit/qunatizers_infrastructure/pytorch/pytorch_node_quantization_dispatcher.py <==
from typing import Dict, List

from model_compression_toolkit.core.common import Logger
from model_compression_toolkit.qunatizers_infrastructure.common.base_quantizer import BaseQuantizer
from model_compression_toolkit.qunatizers_infrastructure.common.node_quantization_dispatcher import \
    NodeQuantizationDispatcher
from model_compression_toolkit.core.common.constants import FOUND_TORCH

if FOUND_TORCH:
    ACTIVATION_QUANTIZERS = "activation_quantizers"
    WEIGHT_QUANTIZERS = "weight_quantizer"


    class PytorchNodeQuantizationDispatcher(NodeQuantizationDispatcher):
        def __init__(self, weight_quantizers: Dict[str, BaseQuantizer] = None,
                     activation_quantizers: List[BaseQuantizer] = None):
            """
            Pytorch Node quantization dispatcher collect all the quantizer of a given layer.

            Args:
                weight_quantizers: A dictionary between weight name to it quantizer .
                activation_quantizers: A list of activation quantization one for each layer output.
            """
            super().__init__(weight_quantizers, activation_quantizers)


else:
    class PytorchNodeQuantizationDispatcher(NodeQuantizationDispatcher):
        def __init__(self, weight_quantizer: Dict[str, BaseQuantizer] = None,
                     activation_quantizers: List[BaseQuantizer] = None):
            """
            Pytorch Node quantization dispatcher collect all the quantizer of a given layer.

            Args:
                weight_quantizers: A dictionary between weight name to it quantizer .
                activation_quantizers: A list of activation quantization one for each layer output.
            """
            super().__init__(weight_quantizer, activation_quantizers)
            Logger.critical('Installing tensorflow and tensorflow_model_optimization is mandatory '
                            'when using PytorchNodeQuantizationDispatcher. '
                            'Could not find Tensorflow package.')

==> mct_nightly-1.7.1.9012023.post357-py3-none-any.whl: model_compression_toolkit/qunatizers_infrastructure/pytorch/pytorch_node_quantization_dispatcher.py <==
from typing import Dict, List

from model_compression_toolkit.core.common import Logger
from model_compression_toolkit.qunatizers_infrastructure import BasePytorchTrainableQuantizer
from model_compression_toolkit.qunatizers_infrastructure.common.base_trainable_quantizer import BaseTrainableQuantizer
from model_compression_toolkit.qunatizers_infrastructure.common.node_quantization_dispatcher import \
    NodeQuantizationDispatcher
from model_compression_toolkit.core.common.constants import FOUND_TORCH

if FOUND_TORCH:
    ACTIVATION_QUANTIZERS = "activation_quantizers"
    WEIGHT_QUANTIZERS = "weight_quantizer"


    class PytorchNodeQuantizationDispatcher(NodeQuantizationDispatcher):
        def __init__(self, weight_quantizers: Dict[str, BasePytorchTrainableQuantizer] = None,
                     activation_quantizers: List[BasePytorchTrainableQuantizer] = None):
            """
            Pytorch Node quantization dispatcher collect all the quantizer of a given layer.

            Args:
                weight_quantizers: A dictionary between weight name to it quantizer .
                activation_quantizers: A list of activation quantization one for each layer output.
            """
            super().__init__(weight_quantizers, activation_quantizers)


else:
    class PytorchNodeQuantizationDispatcher(NodeQuantizationDispatcher):
        def __init__(self, weight_quantizer: Dict[str, BasePytorchTrainableQuantizer] = None,
                     activation_quantizers: List[BasePytorchTrainableQuantizer] = None):
            """
            Pytorch Node quantization dispatcher collect all the quantizer of a given layer.

            Args:
                weight_quantizers: A dictionary between weight name to it quantizer .
                activation_quantizers: A list of activation quantization one for each layer output.
            """
            super().__init__(weight_quantizer, activation_quantizers)
            Logger.critical('Installing tensorflow and tensorflow_model_optimization is mandatory '
                            'when using PytorchNodeQuantizationDispatcher. '
                            'Could not find Tensorflow package.')
